###############
Current roadmap
###############

Consoles
========

* Nintendo (Handheld)

  * Game & Watch
  * Nintendo DSi
  * Nintendo 3DS
  * New Nintendo 3DS

* Nintendo (Home)

  * Wii
  * Wii U

* Sega (Home)

  * Master System
  * Sega CD
  * 32X
  * Saturn
  * Dreamcast

* Sony (Handheld)

  * PlayStation Vita

* Sony (Home)

  * PlayStation 3

Features
========

* More information in the ROMBrowser
* More granular control over compilations
